==> bettertrims-4.0.0%2B1.21.1-fabric-sources.jar: com/bawnorton/bettertrims/mixin/property/ability/post_attack/EnchantmentHelperMixin.java <==
package com.bawnorton.bettertrims.mixin.property.ability.post_attack;

import com.bawnorton.bettertrims.property.TrimProperties;
import com.bawnorton.bettertrims.property.TrimProperty;
import com.bawnorton.bettertrims.property.ability.TrimAbilityComponents;
import com.bawnorton.bettertrims.property.ability.runner.TrimEntityAbilityRunner;
import com.llamalad7.mixinextras.sugar.Local;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

import java.util.function.Consumer;
import net.minecraft.class_1282;
import net.minecraft.class_1297;
import net.minecraft.class_1309;
import net.minecraft.class_1799;
import net.minecraft.class_1890;
import net.minecraft.class_3218;

@Mixin(class_1890.class)
abstract class EnchantmentHelperMixin {
	@Inject(
			//? if 1.21.8 {
			/*method = "doPostAttackEffectsWithItemSourceOnBreak",
			*///?} elif 1.21.1 {
			method = "doPostAttackEffectsWithItemSource",
			//?}
			at = @At("TAIL")
	)
	private static void doTrimPostAttackAbilities(CallbackInfo ci,
	                                              @Local(argsOnly = true) class_3218 level,
	                                              @Local(argsOnly = true) class_1297 entity,
	                                              @Local(argsOnly = true) class_1282 damageSource,
	                                              @Local(argsOnly = true) class_1799 itemSource
	) {
		class_1297 source = damageSource.method_5529();
		if (!(source instanceof class_1309 wearer)) return;

		for (TrimProperty property : TrimProperties.getProperties(level)) {
			for (TrimEntityAbilityRunner<?> ability : property.getEntityAbilityRunners(TrimAbilityComponents.POST_ATTACK)) {
				ability.runDamage(level, wearer, entity, damageSource, itemSource);
			}
		}
	}
}

==> bettertrims-4.0.2%2B1.21.8-fabric-sources.jar: com/bawnorton/bettertrims/mixin/property/ability/post_attack/EnchantmentHelperMixin.java <==
package com.bawnorton.bettertrims.mixin.property.ability.post_attack;

import com.bawnorton.bettertrims.property.TrimProperties;
import com.bawnorton.bettertrims.property.TrimProperty;
import com.bawnorton.bettertrims.property.ability.TrimAbilityComponents;
import com.bawnorton.bettertrims.property.ability.runner.TrimEntityAbilityRunner;
import com.llamalad7.mixinextras.sugar.Local;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

import java.util.function.Consumer;
import net.minecraft.class_1282;
import net.minecraft.class_1297;
import net.minecraft.class_1309;
import net.minecraft.class_1799;
import net.minecraft.class_1890;
import net.minecraft.class_3218;

@Mixin(class_1890.class)
abstract class EnchantmentHelperMixin {
	@Inject(
			//? if >=1.21.8 {
			method = "doPostAttackEffectsWithItemSourceOnBreak",
			//?} else {
			/*method = "doPostAttackEffectsWithItemSource",
			*///?}
			at = @At("TAIL")
	)
	private static void doTrimPostAttackAbilities(
			CallbackInfo ci,
			@Local(argsOnly = true) class_3218 level,
			@Local(argsOnly = true) class_1297 entity,
			@Local(argsOnly = true) class_1282 damageSource,
			@Local(argsOnly = true) class_1799 itemSource
	) {
		class_1297 source = damageSource.method_5529();
		if (!(source instanceof class_1309 wearer)) return;

		for (TrimProperty property : TrimProperties.getProperties(level)) {
			for (TrimEntityAbilityRunner<?> ability : property.getEntityAbilityRunners(TrimAbilityComponents.POST_ATTACK)) {
				ability.runDamage(level, wearer, entity, damageSource, itemSource);
			}
		}
	}
}
